aboutsummaryrefslogtreecommitdiff
path: root/ssl.h
diff options
context:
space:
mode:
authorDavid Sommerseth <dazo@users.sourceforge.net>2010-07-22 22:33:16 +0200
committerDavid Sommerseth <dazo@users.sourceforge.net>2010-07-22 22:33:16 +0200
commit0b026a985d6232d459ed4e2b6642853c959667da (patch)
treea43bbe677b158de41f32bb240358ec4c1d2f34b2 /ssl.h
parentMerge branch 'bugfix2.1' into beta2.2 (diff)
parentFixed static defined length check to use sizeof() (diff)
downloadopenvpn-0b026a985d6232d459ed4e2b6642853c959667da.tar.xz
Merge branch 'feat_misc' into beta2.2
Conflicts: Makefile.am - Copyright update - Added configure.h to CLEANFILES options.c - Copyright update - More verbose information about enabled features Signed-off-by: David Sommerseth <dazo@users.sourceforge.net>
Diffstat (limited to 'ssl.h')
-rw-r--r--ssl.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/ssl.h b/ssl.h
index 5eeca21..02234c3 100644
--- a/ssl.h
+++ b/ssl.h
@@ -278,8 +278,8 @@
* Buffer sizes (also see mtu.h).
*/
/* Maximum length of common name */
#define TLS_CN_LEN 64
/* Legal characters in an X509 or common name */
#define X509_NAME_CHAR_CLASS (CC_ALNUM|CC_UNDERBAR|CC_DASH|CC_DOT|CC_AT|CC_COLON|CC_SLASH|CC_EQUAL)
@@ -288,6 +288,9 @@
/* Maximum length of OCC options string passed as part of auth handshake */
#define TLS_OPTIONS_LEN 512
+/* Default field in X509 to be username */
+#define X509_USERNAME_FIELD_DEFAULT "CN"
+
/*
* Range of key exchange methods
*/
@@ -444,6 +447,7 @@ struct tls_options
/* cert verification parms */
const char *verify_command;
+ const char *verify_export_cert;
const char *verify_x509name;
const char *crl_file;
int ns_cert_type;
@@ -278,8 +278,8 @@
* Buffer sizes (also see mtu.h).
*/
-/* Maximum length of common name */
-#define TLS_CN_LEN 64
+/* Maximum length of the username in cert */
+#define TLS_USERNAME_LEN 64
/* Legal characters in an X509 or common name */
#define X509_NAME_CHAR_CLASS (CC_ALNUM|CC_UNDERBAR|CC_DASH|CC_DOT|CC_AT|CC_COLON|CC_SLASH|CC_EQUAL)